DirectusLoginResult class
The result of a login attempt.
Constructors
- DirectusLoginResult(DirectusLoginResultType type, {String? message})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
An additional error message, if any.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → DirectusLoginResultType
-
The type of login result.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited